# census

A CLI tool to track code metrics

# Installation

`pip install code_census`

# Documentation

The project documentation is available at [https://kracekumar.github.io/code_census/](https://kracekumar.github.io/code_census/).
